# App::hopen::T::Gnu - GNU toolset
package App::hopen::T::Gnu;
use Data::Hopen;
use strict; use warnings;
use Data::Hopen::Base;

our $VERSION = '0.000015'; # TRIAL

=head1 NAME

App::hopen::T::Gnu - GNU toolset for hopen

=head1 SYNOPSIS

This toolset supports any compiler that will accept gcc(1) options, and any
linker that will accept GNU ld(1) options.

=cut

1;
__END__
# vi: set fdm=marker: #
